"""SCons.Tool.mslib

Tool-specific initialization for lib (MicroSoft library archiver).

There normally shouldn't be any need to import this module directly.
It will usually be imported through the generic SCons.Tool.Tool()
selection method.

"""

#
# Copyright (c) 2001, 2002, 2003 Steven Knight
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

__revision__ = "src/engine/SCons/Tool/mslib.py 0.D011 2003/02/11 06:20:12 software"

import SCons.Defaults

from SCons.Platform.win32 import TempFileMunge

def win32ArGenerator(env, target, source, for_signature, **kw):
    args = [ '$AR', '$ARFLAGS', '/OUT:%s' % target[0]]
    args.extend(map(SCons.Util.to_String, source))
    return TempFileMunge(env, args, for_signature)

ArAction = SCons.Action.CommandGenerator(win32ArGenerator)

def generate(env, platform):
    """Add Builders and construction variables for lib to an Environment."""
    env['BUILDERS']['Library'] = SCons.Defaults.StaticLibrary
    env['BUILDERS']['StaticLibrary'] = SCons.Defaults.StaticLibrary
    
    env['AR']          = 'lib'
    env['ARFLAGS']     = '/nologo'
    env['ARCOM']       = ArAction

def exists(env):
    return env.Detect('lib')
